@@ -5,14 +5,13 @@
 """
 import copy
 import json
-import logging
-import os
+
+from unipath import Path
 
 from mootdx.consts import EX_HOSTS, GP_HOSTS, HQ_HOSTS
+from mootdx.logger import log
 from mootdx.utils import get_config_path
 
-logger = logging.getLogger(__name__)
-
 __all__ = ['set', 'get', 'copy', 'update', 'settings']
 
 settings = {
@@ -29,7 +28,8 @@ settings = {
     'TDXDIR': 'C:/new_tdx',
 }
 
-BASE = os.path.dirname(os.path.dirname(__file__))
+# BASE = os.path.dirname(os.path.dirname(__file__))
+BASE = Path(__file__).parent.parent
 CONF = get_config_path('config.json')
 
 
@@ -43,41 +43,43 @@ def setup():
     try:
         options = json.load(open(CONF))
         settings.update(options)
-    except Exception:
-        logger.error(
-            '未找到配置文件 config.json. 请在命令行运行 "mootdx bestip -w -v" 生成配置文件')
+    except Exception as e:
+        log.error(e)
+        log.error('未找到配置文件 config.json. 请在命令行运行 "mootdx bestip -w -v" 生成配置文件')
 
     return True if settings else False
 
 
 def has(key, value):
-    '''
+    """
     通过 key 设置某一项值
 
     :param key:
     :param value:
     :return:
-    '''
+    """
     return value in settings[key]
 
 
 def set(key, value):
-    '''
+    """
     通过 key 设置某一项值
+
     :param key:
     :param value:
     :return:
-    '''
+    """
     settings[key] = value
 
 
 def get(key, default=None):
-    '''
+    """
     通过 key 获取值
+
     :param key:
     :param default:
     :return:
-    '''
+    """
     key = key.split('.')
     cfg = settings.get(key[0])
 
@@ -93,30 +95,30 @@ def get(key, default=None):
 
 
 def path(key, value=None):
-    '''
+    """
     通过 key 构建路径
+
     :param key:
     :param value:
     :return:
-    '''
-    path = settings.get(key)
-    path = os.path.join(BASE, path, value)
-
-    return path
+    """
+    return Path(BASE, settings.get(key), value)
 
 
 def clone():
-    '''
+    """
     复制配置
+
     :return:
-    '''
+    """
     return copy.deepcopy(settings)
 
 
 def update(options):
-    '''
+    """
     全部替换配置
+
     :param options:
     :return:
-    '''
+    """
     settings.update(options)
