@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-import os
 
-from pytdx.reader import (BlockReader, CustomerBlockReader, TdxDailyBarReader,
-                          TdxExHqDailyBarReader, TdxLCMinBarReader)
+from pytdx.reader import (BlockReader, CustomerBlockReader, TdxExHqDailyBarReader, TdxLCMinBarReader)
+from unipath import Path
 
 from mootdx.consts import TYPE_GROUP
+from mootdx.contrib.compat import MooTdxDailyBarReader
 from mootdx.logger import log
 from mootdx.utils import get_stock_market
 
@@ -39,7 +39,7 @@ class ReaderBase(object):
         :param tdxdir: 通达信安装目录
         """
 
-        if os.path.isdir(tdxdir):
+        if Path(tdxdir).isdir():
             self.tdxdir = tdxdir
         else:
             log.error('tdxdir 目录不存在')
@@ -57,15 +57,13 @@ class ReaderBase(object):
         prefix = market if len(symbol.split('#')) == 1 else ''
         ext = ext if isinstance(ext, list) else [ext]
 
-        for t in ext:
-            vipdoc = 'vipdoc/{}/{}/{}{}.{}'.format(market, subdir, prefix,
-                                                   symbol, t)
-            vipdoc = os.path.join(self.tdxdir, vipdoc)
+        for ex_ in ext:
+            vipdoc = Path(self.tdxdir, market, subdir, prefix, symbol, ex_)
 
-            if os.path.exists(vipdoc):
+            if not Path(vipdoc).exists():
                 return vipdoc
             else:
-                log.error('未找到所需的文件: {}'.format(vipdoc))
+                log.debug('未找到所需的文件: {}'.format(vipdoc))
 
         return None
 
@@ -80,7 +78,7 @@ class StdReader(ReaderBase):
         :param symbol:
         :return: pd.dataFrame or None
         """
-        reader = TdxDailyBarReader()
+        reader = MooTdxDailyBarReader()
         vipdoc = self.find_path(symbol=symbol, subdir='lday', ext='day')
 
         if vipdoc is not None:
@@ -121,14 +119,14 @@ class StdReader(ReaderBase):
         """
         if custom:
             reader = CustomerBlockReader()
-            vipdoc = os.path.join(self.tdxdir, 'T0002', 'blocknew', '{}'.format(symbol))
+            vipdoc = Path(self.tdxdir, 'T0002', 'blocknew', f'{symbol}')
         else:
             reader = BlockReader()
-            vipdoc = os.path.join(self.tdxdir, 'T0002', 'hq_cache', '{}.dat'.format(symbol))
+            vipdoc = Path(self.tdxdir, 'T0002', 'hq_cache', f'{symbol}.dat')
 
         fmt = TYPE_GROUP if group else None
 
-        if os.path.exists(vipdoc):
+        if Path(vipdoc).exists():
             return reader.get_df(vipdoc, fmt)
         else:
             log.error('未找到所需的文件: {}'.format(vipdoc))
