@@ -2,11 +2,12 @@
 import logging
 import socket
 import time
+
 from prettytable import PrettyTable
 
 from mootdx.consts import EX_HOSTS, GP_HOSTS, HQ_HOSTS
+from mootdx.logger import log
 
-logger = logging.getLogger(__name__)
 result = []
 
 hosts = {
@@ -59,11 +60,10 @@ def Server(index=None, limit=5, console=False, verbose=False):
             proxy['time'] = (time.perf_counter() - start) * 1000
 
             server.append(proxy)
-            logger.info("{}:{} 验证通过，响应时间：{:5.2f} ms.".format(
-                proxy.get('addr'), proxy.get('port'), proxy.get('time')))
+            log.info("{}:{} 验证通过，响应时间：{:5.2f} ms.".format(proxy.get('addr'), proxy.get('port'), proxy.get('time')))
         except Exception as e:
-            logger.debug(e)
-            logger.warning("{},{} 验证失败.".format(proxy.get('addr'), proxy.get('port')))
+            log.error(e)
+            log.warning("{},{} 验证失败.".format(proxy.get('addr'), proxy.get('port')))
 
     # 结果按响应时间从小到大排序
     server.sort(key=lambda item: item['time'])
